@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2018 Free Software Foundation, Inc.
+# Copyright (C) 2011-2021 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ parse.y:
 	:; { : \
 	  && echo "%{" \
 	  && echo "int yylex () { return 0; }" \
-	  && echo "void yyerror (char *s) {}" \
+	  && echo "void yyerror (const char *s) {}" \
 	  && echo "%}" \
 	  && echo "%%" \
 	  && echo "maude : 'm' 'a' 'u' 'd' 'e' {}"; \
